==> kubernetes-client-4.13.3-sources.jar: io/fabric8/kubernetes/client/dsl/internal/metrics/v1beta1/NodeMetricsOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.metrics.v1beta1.DoneableNodeMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.DoneableNodeMetrics;

import java.util.Map;
import java.util.TreeMap;


public class NodeMetricsOperationsImpl extends HasMetadataOperation<NodeMetrics, NodeMetricsList, DoneableNodeMetrics, Resource<NodeMetrics, DoneableNodeMetrics>> {

  public NodeMetricsOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NodeMetricsOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NodeMetricsOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("metrics.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("nodemetrics"));
    this.type = NodeMetrics.class;
    this.listType = NodeMetricsList.class;
    this.doneableType = DoneableNodeMetrics.class;
  }

  public NodeMetricsOperationsImpl newInstance(OperationContext context) {
    return new NodeMetricsOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> kubernetes-client-5.6.0-sources.jar: io/fabric8/kubernetes/client/dsl/internal/metrics/v1beta1/NodeMetricsOperationsImpl.java <==

                                          
      

package io.fabric8.kubernetes.client.dsl.internal.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetrics;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsBuilder;
import io.fabric8.kubernetes.api.model.metrics.v1beta1.NodeMetricsList;

import java.util.Map;
import java.util.TreeMap;


public class NodeMetricsOperationsImpl extends HasMetadataOperation<NodeMetrics, NodeMetricsList, Resource<NodeMetrics>> {

  public NodeMetricsOperationsImpl(OkHttpClient client, Config config) {
    this(client, config, null);
  }

  public NodeMetricsOperationsImpl(OkHttpClient client, Config config, String namespace) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withNamespace(namespace).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public NodeMetricsOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("metrics.k8s.io")
    .withApiGroupVersion("v1beta1")
    .withPlural("nodemetrics"));
    this.type = NodeMetrics.class;
    this.listType = NodeMetricsList.class;
  }

  public NodeMetricsOperationsImpl newInstance(OperationContext context) {
    return new NodeMetricsOperationsImpl(context);
  }

  @Override
  public NodeMetrics edit(Visitor... visitors) {
    return patch(new NodeMetricsBuilder(getMandatory()).accept(visitors).build());
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
